@@ -1,11 +1,9 @@
 package Dist::Zilla::PluginBundle::TAPPER;
-# git description: v0.003-2-gf419560
+# git description: v0.004-1-gb6a6b12
 
-BEGIN {
-  $Dist::Zilla::PluginBundle::TAPPER::AUTHORITY = 'cpan:TAPPER';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Build your distributions like TAPPER does
-$Dist::Zilla::PluginBundle::TAPPER::VERSION = '0.004';
+$Dist::Zilla::PluginBundle::TAPPER::VERSION = '0.005';
 use Moose 1.00;
 use Method::Signatures::Simple;
 use Moose::Util::TypeConstraints;
@@ -380,11 +378,12 @@ method configure {
     $self->add_plugins(['NextRelease' =>
                        { format => '%-9v %{yyyy-MM-dd}d' }]);
 
-    $self->add_plugins(['Git::CheckFor::CorrectBranch' =>
-                        { release_branch => ($self->has_release_branch
-                                             ? $self->release_branch
-                                             : 'master')
-                        }]);
+    # Not required anymore as we release from branches nowadays
+    # $self->add_plugins(['Git::CheckFor::CorrectBranch' =>
+    #                     { release_branch => ($self->has_release_branch
+    #                                          ? $self->release_branch
+    #                                          : 'master')
+    #                     }]);
 
     if ($self->has_static_version) {
             $self->add_plugins(['StaticVersion' => { version => $self->static_version }]);
@@ -405,7 +404,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
